# Dart utilities
The `nodejs_interop` library provides helper functions easing the manipulation of [JavaScript](https://developer.mozilla.org/en-US/docs/Web/JavaScript)-[Node.js](https://nodejs.org)-[Dart](https://www.dartlang.org) types.

## `Future<T> convertToFuture<T>(Promise<T> promise)`
Converts a JavaScript `Promise` to a Dart `Future`:

```dart
var completer = allowInterop((resolve, reject) => resolve('foo'));
var future = convertToFuture(new Promise<String>(completer));
print(await promise); // "foo"
```

## `Stream<T> convertToStream<T>(Readable<T> readable)`
Converts a Node.js `Readable` stream to a Dart `Stream`:

```dart
// TODO
```

## `dynamic dartify(dynamic value)`
Recursively converts a JavaScript value to a Dart object:

```dart
var jsArray = jsify(['foo', 'bar', {'baz': 'qux'}]);
var dartList = dartify(jsArray);

print(dartList is List); // true
print(dartList.first is String); // true
print(dartList.last is Map); // true

var jsObject = jsify({'foo': 'bar', 'baz': ['qux']});
var dartMap = dartify(jsObject);

print(dartMap is Map); // true
print(dartMap.values.first is String); // true
print(dartMap.values.last is List); // true
```

## `T loadLibrary<T>(String identifier, {T onError(String identifier)})`
Requires a Node.js module:

```dart
// Instead of importing a module by using the `require()` function...
final PathModule path = require('path');

// ...use the `loadLibrary()` function to import the exported types.
final path = loadLibrary<PathModule>('path');
```

This function is prefered to the Node.js `require()` function because it properly exposes to the Dart engine the types exported by the required module.
