# npm packages
The `nodejs_interop` library provides interoperability with a predefined set of [npm](https://nodejs.org) packages.

These packages are used internally to provide features not natively supported by [Node.js](https://nodejs.org) APIs. As such, they are not publicly exported by the library.

If you still want to use the APIs of these packages, add this statement in your [Dart](https://www.dartlang.org) code:

```dart
import 'package:nodejs_interop/nodejs_interop.dart';
import 'package:nodejs_interop/src/npm.dart';
```

## The [`del`](https://www.npmjs.com/package/del) package
This package is used to recursively delete a directory and all its sub-directories and files:

```dart
DelModule del = require('del');

var options = new DeleteOptions(dryRun: true);
var files = await convertToFuture(del('path/to/**/*.dart', options));
print(files); // ["path/to/file1.dart", "path/to/subdir1/file2.dart", ...]
```

## The [`ipaddr.js`](https://www.npmjs.com/package/ipaddr.js) package
This package is used to parse and validate Internet addresses:

```dart
IPAddrModule ipaddr = require('ipaddr.js');

var address = '::ffff:163.172.221.182';
print(ipaddr.isValid(address)); // true
print(ipaddr.parse(address).toString()); // "::ffff:a3ac:ddb6"
print(ipaddr.process(address).toString()); // "163.172.221.182"
```

## The [`make-dir`](https://www.npmjs.com/package/make-dir) package
This package is used to recursively create all non-existing path components of a file system entity:

```dart
MakeDirModule makeDir = require('make-dir');

var options = new MakeDirOptions(mode: int.parse('755', radix: 8));
await convertToFuture(makeDir('path/to/dir', options));
```

## The [`os-locale`](https://www.npmjs.com/package/os-locale) package
This package is used to get the name of the current locale:

```dart
OSLocaleModule osLocale = require('os-locale');

var options = new OSLocaleOptions(spawn: false);
print(await convertToFuture(osLocale(options))); // "en_US"
```

## The [`readdir-enhanced`](https://www.npmjs.com/package/readdir-enhanced) package
This package is used to recursively list the sub-directories and files of a directory:

```dart
ReaddirModule readdir = require('readdir-enhanced');

var options = new ReaddirOptions(deep: true);
var files = await convertToFuture(readdir('path/to/dir', options));
print(files); // ["subdir1", "subdir1/file.txt", "subdir1/subdir2", ...]
```

## The [`supports-color`](https://www.npmjs.com/package/supports-color) package
This package is used to determine if ANSI codes are supported when `stdout` is connected to a terminal:

```dart
SupportsColorModule supportsColor = require('supports-color');

print(supportsColor.stderr); // false
print(supportsColor.stdout.has256); // true
```
