import 'package:js/js.dart';
import 'package:nodejs_interop/nodejs_interop.dart';
import 'package:test/test.dart';

/// Tests the features of the [Promise] class.
void main() => group('Promise', () {
  group('.all()', () {
    test('should return a promise that completes with the collected values from the given promises', () async {
      var promises = [Promise.resolve(1), Promise.resolve(2), Promise.resolve(3)];
      expect(await convertToFuture(Promise.all(promises)), orderedEquals([1, 2, 3]));
    });
  });

  group('.race()', () {
    test('should return a promise that completes with the value from the first promise to resolve', () async {
      var promises = [Promise.resolve(1), Promise.resolve(2), Promise.resolve(3)];
      expect(await convertToFuture(Promise.race(promises)), equals(1));
    });
  });

  group('.reject()', () {
    test('should return a promise that rejects', () {
      expect(convertToFuture(Promise.reject('foo')), throwsA(equals('foo')));
    });
  });

  group('.resolve()', () {
    test('should return a promise that resolves', () async {
      expect(await convertToFuture(Promise.resolve('foo')), equals('foo'));
    });
  });

  group('.then()', () {
    test('should invoke the `onFulfilled` handler if the promise resolved', () async {
      var promise = new Promise<String>(allowInterop((resolve, reject) => resolve('resolved')));
      expect(await convertToFuture(promise), equals('resolved'));
    });

    test('should invoke the `onRejected` handler if the promise rejected', ()  {
      var promise = new Promise<String>(allowInterop((resolve, reject) => reject('rejected')));
      expect(convertToFuture(promise), throwsA(equals('rejected')));
    });
  });
});
