import 'dart:async';
import 'package:js/js.dart';
import 'package:nodejs_interop/nodejs_interop.dart';
import 'package:test/test.dart';

/// Tests the features of the [DnsModule] class.
void main() => group('DnsModule', () {
  final dns = loadLibrary<DnsModule>('dns');
  final net = loadLibrary<NetModule>('net');

  group('.lookup()', () {
    test('should resolve the hostname into the first found IP address', () async {
      var completer = new Completer<List>();
      dns.lookup('belin.io', allowInterop((error, [address, family]) {
        if (error != null) completer.completeError(error);
        else completer.complete([address, family]);
      }));

      var result = await completer.future;
      expect(net.isIPv4(result.first), isTrue);
      expect(result.last, equals(4));
    });

    test('should resolve the hostname into an IPv6 address', () async {
      var completer = new Completer<List>();
      dns.lookup('google.com', 6, allowInterop((error, [address, family]) {
        if (error != null) completer.completeError(error);
        else completer.complete([address, family]);
      }));

      var result = await completer.future;
      expect(net.isIPv6(result.first), isTrue);
      expect(result.last, equals(6));
    });

    test('should resolve the hostname into a list of IP addresses', () async {
      var completer = new Completer<List>();
      dns.lookup('belin.io', new LookupOptions(all: true), allowInterop((error, [addresses]) {
        if (error != null) completer.completeError(error);
        else completer.complete(addresses);
      }));

      var result = (await completer.future).single;
      expect(result, const isInstanceOf<IPAddress>());
      expect(net.isIPv4(result.address), isTrue);
      expect(result.family, equals(4));
    });
  });

  group('.lookupService()', () {
    test('should resolve the given address and port into a `hostname` and `service`', () async {
      var completer = new Completer<List<String>>();
      dns.lookupService('163.172.221.182', 80, allowInterop((error, [hostname, service]) {
        if (error != null) completer.completeError(error);
        else completer.complete([hostname, service]);
      }));

      var result = await completer.future;
      expect(result.first, equals('ns.belin.io'));
      expect(result.last, equals('http'));
    });
  });
});
