import 'dart:js_util';
import 'package:nodejs_interop/nodejs_interop.dart';
import 'package:nodejs_interop/src/npm.dart';
import 'package:test/test.dart';

/// Tests the features of the `supports-color` package.
void main() => group('SupportsColorModule', () {
  SupportsColorModule loadModule({bool enableColor = false}) {
    Reflect.deleteProperty(require.cache, require.resolve('supports-color'));
    setProperty(process.env, 'FORCE_COLOR', enableColor ? '1' : '0');
    return require('supports-color');
  }

  group('.stderr', () {
    test('should be `false` when used with the test runner', () {
      expect(loadModule(enableColor: false).stderr, isFalse);
    });

    test('should be `true` when used with the `FORCE_COLOR` environment variable', () {
      var colorLevel = loadModule(enableColor: true).stderr;
      expect(colorLevel, const isInstanceOf<ColorSupportLevel>());
      expect(colorLevel.hasBasic, isTrue);
    });
  });

  group('.stdout', () {
    test('should be `false` when used with the test runner', () {
      expect(loadModule(enableColor: false).stdout, isFalse);
    });

    test('should be `true` when used with the `FORCE_COLOR` environment variable', () {
      var colorLevel = loadModule(enableColor: true).stdout;
      expect(colorLevel, const isInstanceOf<ColorSupportLevel>());
      expect(colorLevel.hasBasic, isTrue);
    });
  });
});
