import 'dart:js_util';
import 'package:js/js.dart';
import 'package:nodejs_interop/nodejs_interop.dart';
import 'package:test/test.dart';

/// Tests the features of the `nodejs_interop.util` library.
void main() {
  group('convertToFuture()', () {
    test('should return a future that completes with a value when the promise resolves', () async {
      var promise = new Promise<String>(allowInterop((resolve, reject) => resolve('foo')));
      expect(await convertToFuture(promise), equals('foo'));
    });

    test('should return a future that completes with an error when the promise rejects', () {
      var promise = new Promise<String>(allowInterop((resolve, reject) => reject(new Exception())));
      expect(convertToFuture(promise), throwsException);
    });
  });

  group('convertToStream()', () {
    var values = const ['foo', 'bar', 'baz', 'qux', 'quux'];
    var options = new ReadableOptions(read: allowInteropCaptureThis((self, size) => self.push(size.toString())));
    loadLibrary('stream');

    test('should convert an empty `Readable` into an empty stream', () {
      //expect(convertToStream(new Readable<String>(options)), emitsDone);
    }, skip: true);

    test('should TODO', () async { // TODO
      var readable = new Readable<String>(options); //..push('foo')..push('bar');
      expect(await convertToStream(readable).toList(), orderedEquals(['foo', 'bar']));
    }, skip: true);
  });

  group('dartify()', () {
    test('should leave unchanged the supported Dart types', () {
      var now = new DateTime.now();
      expect(dartify(null), isNull);
      expect(dartify(false), isFalse);
      expect(dartify(123), equals(123));
      expect(dartify(-123.456), equals(-123.456));
      expect(dartify(now), equals(now));
      expect(dartify('foo'), equals('foo'));
    });

    test('should convert the supported JavaScript types', () {
      var array = jsify([]);
      expect(dartify(array), allOf(isList, isEmpty));
      array.push('foo');
      expect(dartify(array), allOf(isList, hasLength(1), contains('foo')));

      var object = newObject();
      expect(dartify(object), allOf(isMap, isEmpty));
      setProperty(object, 'foo', 'bar');
      expect(dartify(object), allOf(isMap, hasLength(1), containsPair('foo', 'bar')));
    });
  });
}
